Crate kcr_imaging_ingestion_alvearie_org

Crate kcr_imaging_ingestion_alvearie_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the imaging-ingestion.alvearie.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

imaging-ingestion.alvearie.org/v1alpha1

  • DicomEventBridge
  • DicomEventDrivenIngestion
  • DicomInstanceBinding
  • DicomStudyBinding
  • DicomwebIngestionService
  • DimseIngestionService
  • DimseProxy

Modules

v1alpha1