This crate contains kube-rs compatible bindings for Kubernetes custom resources for the imaging-ingestion.alvearie.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
imaging-ingestion.alvearie.org/v1alpha1
DicomEventBridgeDicomEventDrivenIngestionDicomInstanceBindingDicomStudyBindingDicomwebIngestionServiceDimseIngestionServiceDimseProxy